1.0.0 API documentation: GLM_GTX_extend

| 1.0.0 API documentation

Functions
GLM_GTX_extend
Experimental extensions

## Functions
template<typename genType >
GLM_FUNC_DECL genType | extend (genType const &Origin, genType const &Source, typename genType::value_type const Length)
| Extends of Length the Origin position using the (Source - Origin) direction. More...

## Detailed Description

Include <glm/gtx/extend.hpp> to use the features of this extension.

Extend a position from a source to a position at a defined length.

## Function Documentation

## ◆ extend()

GLM_FUNC_DECL genType glm::extend | ( | genType const & | Origin,
|  | genType const & | Source,
|  | typename genType::value_type const | Length
| ) |  |

Extends of Length the Origin position using the (Source - Origin) direction.

See also
  GLM_GTX_extend